RegisterAllocator

Struct RegisterAllocator 

pub struct RegisterAllocator<const N: usize> { /* private fields */ }
Cheap and cheerful single-pass register allocation

Implementations

Source

impl<const N: usize> RegisterAllocator<N>

pub fn new(size: usize) -> Self

Builds a new RegisterAllocator.

pub fn empty() -> Self

Build a new empty register allocator

pub fn reset(&mut self, size: usize, tape: RegTape)

Resets internal state, reusing allocations and the provided tape

This must be called after the allocator is finalized (removing the internal RegTape).

Panics

If the internal tape is not empty

pub fn finalize(&mut self) -> RegTape

Claims the internal RegTape, leaving the allocator empty

pub fn op(&mut self, op: SsaOp)

Allocates the next operation in the tape