pub enum Op {
Input(Var),
Const(OrderedFloat<f64>),
Binary(BinaryOpcode, Node, Node),
Unary(UnaryOpcode, Node),
}Expand description
An operation in a math expression
Ops should be constructed by calling functions on
Context, e.g.
Context::add will generate an
Op::Binary(BinaryOpcode::Add, .., ..) node and return an opaque handle.
Each Op is tightly coupled to the Context
which generated it, and will not be valid for a different Context.
Variants
Implementations
Sourceimpl Op
impl Op
Sourcepub fn dot_node_color(&self) -> &str
pub fn dot_node_color(&self) -> &str
Returns the color to be used in a GraphViz drawing for this node
Sourcepub fn dot_node_shape(&self) -> &str
pub fn dot_node_shape(&self) -> &str
Returns the shape to be used in a GraphViz drawing for this node
Sourcepub fn iter_children(&self) -> impl Iterator<Item = Node>
pub fn iter_children(&self) -> impl Iterator<Item = Node>
Iterates over children, producing 0, 1, or 2 values