TreeOp

Enum TreeOp 

pub enum TreeOp {
    Input(Var),
    Const(f64),
    Binary(BinaryOpcode, Arc<TreeOp>, Arc<TreeOp>),
    Unary(UnaryOpcode, Arc<TreeOp>),
    RemapAxes {
        target: Arc<TreeOp>,
        x: Arc<TreeOp>,
        y: Arc<TreeOp>,
        z: Arc<TreeOp>,
    },
    RemapAffine {
        target: Arc<TreeOp>,
        mat: Affine3<f64>,
    },
}
Opcode type for trees

This is equivalent to Op, but also includes the RemapAxes and TreeOp::RemapAffine operations for lazy remapping.

Variants



Input(Var)

Input (an arbitrary Var)



Const(f64)



Binary(BinaryOpcode, Arc<TreeOp>, Arc<TreeOp>)



Unary(UnaryOpcode, Arc<TreeOp>)



RemapAxes

Lazy remapping of trees

When imported into a Context, all x/y/z clauses within target will be replaced with the provided x/y/z trees.

If the transform is affine, then RemapAffine should be preferred, because it flattens sequences of affine transformations.

Fields

target: Arc<TreeOp>


RemapAffine

Lazy affine transforms

When imported into a Context, the x/y/z clauses within target will be transformed with the provided affine matrix.

Fields

target: Arc<TreeOp>