Tree

Struct Tree 

pub struct Tree(/* private fields */);
Owned handle for a standalone math tree

Implementations

Source

impl Tree

pub fn axes() -> (Self, Self, Self)

Returns an (x, y, z) tuple

pub fn as_ptr(&self) -> *const TreeOp

Returns a pointer to the inner TreeOp

This can be used as a strong (but not unique) identity.

pub fn ptr_eq(&self, other: &Self) -> bool

Shallow (pointer) equality check

pub fn remap_xyz(&self, x: Tree, y: Tree, z: Tree) -> Tree

Remaps the axes of the given tree

If the mapping is affine, then remap_affine should be preferred.

The remapping is lazy; it is not evaluated until the tree is imported into a Context.

pub fn remap_affine(&self, mat: Affine3<f64>) -> Tree

Performs an affine remapping of the given tree

The remapping is lazy; it is not evaluated until the tree is imported into a Context.

pub fn var(&self) -> Option<Var>

Returns the inner Var if this is an input tree, or None

pub fn deriv(&self, v: Var) -> Tree

Performs symbolic differentiation with respect to the given variable

pub fn pow(&self, n: i64) -> Self

Raises this tree to the power of an integer using exponentiation by squaring

Source

impl Tree

See Context for documentation of these functions

pub fn x() -> Self

pub fn y() -> Self

pub fn z() -> Self

pub fn constant(f: f64) -> Self

pub fn square(&self) -> Self

pub fn floor(&self) -> Self

pub fn ceil(&self) -> Self

pub fn round(&self) -> Self

pub fn sqrt(&self) -> Self

pub fn max<T: Into<Tree>>(&self, other: T) -> Self

pub fn min<T: Into<Tree>>(&self, other: T) -> Self

pub fn compare<T: Into<Tree>>(&self, other: T) -> Self

pub fn modulo<T: Into<Tree>>(&self, other: T) -> Self

pub fn and<T: Into<Tree>>(&self, other: T) -> Self

pub fn or<T: Into<Tree>>(&self, other: T) -> Self

pub fn atan2<T: Into<Tree>>(&self, other: T) -> Self

pub fn neg(&self) -> Self

pub fn recip(&self) -> Self

pub fn sin(&self) -> Self

pub fn cos(&self) -> Self

pub fn tan(&self) -> Self

pub fn asin(&self) -> Self

pub fn acos(&self) -> Self

pub fn atan(&self) -> Self

pub fn exp(&self) -> Self

pub fn ln(&self) -> Self

pub fn not(&self) -> Self

pub fn abs(&self) -> Self