pub enum Error {
Show 19 variants
BadNode,
BadVar,
MissingVar(Var),
NotAVar,
NotAConst,
EmptyContext,
EmptyMap,
UnknownOpcode(String),
UnknownVariable(String),
EmptyFile,
BadChoiceSlice(usize, usize),
MismatchedSlices,
BadVarSlice(usize, usize),
BadVarIndex(usize, usize),
SingularMatrix(&'static str),
IoError(Error),
BadTileSize(usize, usize),
BadTileOrder(usize, usize),
EmptyTileSizes,
}Expand description
Universal error type for Fidget
Variants
BadNode
Node is not present in this Context
BadVar
Variable is not present in this Context
MissingVar(Var)
Variable is missing in the evaluation map
NotAVar
The given node does not have an associated variable
NotAConst
The given node is not a constant
EmptyContext
Context is empty
EmptyMap
IndexMap is empty
UnknownOpcode(String)
Unknown opcode {0}
UnknownVariable(String)
Unknown variable {0}
EmptyFile
Empty file
BadChoiceSlice(usize, usize)
Choice slice length does not match choice count
MismatchedSlices
Variable slice lengths are mismatched
BadVarSlice(usize, usize)
Variable slice length does not match expected count
BadVarIndex(usize, usize)
Variable index exceeds max var index for this tape
SingularMatrix(&'static str)
Could not solve for matrix pseudo-inverse
IoError(Error)
IO error; see inner code for details
BadTileSize(usize, usize)
Each tile must be divisible by subsequent tiles
BadTileOrder(usize, usize)
Tile size list must be in descending order
EmptyTileSizes
Tile size list must not be empty