Module eval

Module eval 

Traits and data structures for function evaluation

Structs

BulkEvalError
Error type for bulk evaluation
BulkOutput
Container for bulk output results
TracingEvalError
Error type for tracing evaluation

Traits

BulkEvaluator
Trait for bulk evaluation returning the given type T
Function
A function represents something that can be evaluated
MathFunction
A Function which can be built from a math expression
Tape
A tape represents something that can be evaluated by an evaluator
Trace
Represents the trace captured by a tracing evaluation
TracingEvaluator
Evaluator for single values which simultaneously captures an execution trace