MathFunction

Trait MathFunction 

pub trait MathFunction: Function {
    // Required method
    fn new(ctx: &Context, nodes: &[Node]) -> Result<Self, Error>
       where Self: Sized;
}
A Function which can be built from a math expression

Required Methods

fn new(ctx: &Context, nodes: &[Node]) -> Result<Self, Error>
where Self: Sized,

Builds a new function from the given context and node

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors