Module render

Module render 

Common types for all kinds of rendering

Structs

CancelToken
Token to cancel an in-progress operation
RegionSize
Image size in pixels, used to generate a screen-to-world matrix
RenderHandle
A RenderHandle contains lazily-populated tapes for rendering
TileSizes
Container representing an ordered, checked list of tile sizes

Enums

ThreadPool
Thread pool to use for multithreaded rendering
TileSizeError
Error type when constructing a TileSizes list

Traits

RenderHints
Hints for how to render this particular type

Type Aliases

ImageSize
Size for 2D rendering of an image
VoxelSize
Size for 3D rendering of an image