RegionSize

Struct RegionSize 

pub struct RegionSize<const N: usize>{ /* private fields */ }
Image size in pixels, used to generate a screen-to-world matrix

The screen coordinate space is the following:

       0 ------------> width
       |             |
       |             |
       |             |
       V--------------
  height

The map from screen to world coordinates (generated by screen_to_world) is as following:

      -1           y = +1
       0-------------^-------------> width
       |             |             |
       |             |             |
       |             |             |
  x = -1 <-----------0-------------> x = +1
       |             |             |
       |             |             |
       |             V             |
       V---------- y = -1 ---------
  height

(with +z pointing out of the screen)

Note that the Y axis is reversed between screen and world coordinates: screen coordinates have +y pointing down, but world coordinates have it pointing up. For both X and Y coordinates, the +1 value is located one pixel beyond the edge of the screen region (off the right edge for X, and off the top edge for Y).

If the render region is not square, then the shorter axis is clamped to ±1 and the longer axis will exceed that value.

Implementations

Source

impl<const N: usize> RegionSize<N>

Apologies for the terrible trait bounds; they’re necessary to persuade the internals to type-check, but shouldn’t be noticeable to library users.

pub fn screen_to_world( &self, ) -> OMatrix<f32, <Const<N> as DimNameAdd<Const<1>>>::Output, <Const<N> as DimNameAdd<Const<1>>>::Output>

Builds a matrix that converts from screen to world coordinates

See the struct docstring for a diagram of this mapping.

pub fn width(&self) -> u32

Returns the width of the image (in pixels or voxels)

pub fn height(&self) -> u32

Returns the height of the image (in pixels or voxels)

Source

impl RegionSize<2>

pub fn new(width: u32, height: u32) -> Self

Builds a new ImageSize object from width and height in pixels

pub fn transform_point(&self, p: Point2<i32>) -> Point2<f32>

Transforms a point from screen to world coordinates

Source

impl RegionSize<3>

pub fn new(width: u32, height: u32, depth: u32) -> Self

Builds a new VoxelSize object from width, height, and depth in voxels

pub fn depth(&self) -> u32

Returns the depth of the image (in voxels)

pub fn transform_point(&self, p: Point3<i32>) -> Point3<f32>

Transforms a point from screen to world coordinates