RenderHandle

Struct RenderHandle 

pub struct RenderHandle<F: Function, T = ()> { /* private fields */ }
A RenderHandle contains lazily-populated tapes for rendering

This can be cheaply cloned, although it is usually passed by mutable reference to a recursive function.

The most recent simplification is cached for reuse (if the trace matches).

Implementations

Source

impl<F: Function, T> RenderHandle<F, T>

pub fn new(shape: Shape<F, T>) -> Self

Build a new RenderHandle for the given shape

None of the tapes are populated here.

pub fn i_tape( &mut self, storage: &mut Vec<F::TapeStorage>, ) -> &ShapeTape<<F::IntervalEval as TracingEvaluator>::Tape>

Returns a tape for tracing interval evaluation

pub fn f_tape( &mut self, storage: &mut Vec<F::TapeStorage>, ) -> &ShapeTape<<F::FloatSliceEval as BulkEvaluator>::Tape>

Returns a tape for bulk float evaluation

pub fn g_tape( &mut self, storage: &mut Vec<F::TapeStorage>, ) -> &ShapeTape<<F::GradSliceEval as BulkEvaluator>::Tape>

Returns a tape for bulk gradient evaluation

pub fn simplify( &mut self, trace: &F::Trace, workspace: &mut F::Workspace, shape_storage: &mut Vec<F::Storage>, tape_storage: &mut Vec<F::TapeStorage>, ) -> &mut Self

Simplifies the shape with the given trace

As an internal optimization, this may reuse a previous simplification if the trace matches.

pub fn recycle( self, shape_storage: &mut Vec<F::Storage>, tape_storage: &mut Vec<F::TapeStorage>, )

Recycles the entire handle into the given storage vectors