Shape

Struct Shape 

pub struct Shape<F> { /* private fields */ }
A shape represents an implicit surface with X/Y/Z variables

It is mostly agnostic to how that surface is represented, wrapping a Function and a set of axes.

Shapes are shared between threads, so they should be cheap to clone. In most cases, they’re a thin wrapper around an Arc<..>.

Implementations

Source

impl<F: Function + Clone> Shape<F>

pub fn new_point_eval() -> ShapeTracingEval<F::PointEval>

Builds a new point evaluator

pub fn new_interval_eval() -> ShapeTracingEval<F::IntervalEval>

Builds a new interval evaluator

pub fn new_float_slice_eval() -> ShapeBulkEval<F::FloatSliceEval>

Builds a new float slice evaluator

pub fn new_grad_slice_eval() -> ShapeBulkEval<F::GradSliceEval>

Builds a new gradient slice evaluator

pub fn point_tape( &self, storage: F::TapeStorage, ) -> ShapeTape<<F::PointEval as TracingEvaluator>::Tape>

Returns an evaluation tape for a point evaluator

pub fn interval_tape( &self, storage: F::TapeStorage, ) -> ShapeTape<<F::IntervalEval as TracingEvaluator>::Tape>

Returns an evaluation tape for a interval evaluator

pub fn float_slice_tape( &self, storage: F::TapeStorage, ) -> ShapeTape<<F::FloatSliceEval as BulkEvaluator>::Tape>

Returns an evaluation tape for a float slice evaluator

pub fn grad_slice_tape( &self, storage: F::TapeStorage, ) -> ShapeTape<<F::GradSliceEval as BulkEvaluator>::Tape>

Returns an evaluation tape for a gradient slice evaluator

pub fn simplify( &self, trace: &F::Trace, storage: F::Storage, workspace: &mut F::Workspace, ) -> Result<Self, BadTrace>
where Self: Sized,

Computes a simplified tape using the given trace, and reusing storage

pub fn recycle(self) -> Option<F::Storage>

Attempt to reclaim storage from this shape

This may fail, because shapes are Clone and are often implemented using an Arc around a heavier data structure.

pub fn size(&self) -> usize

Returns a size associated with this shape

This is underspecified and only used for unit testing; for tape-based shapes, it’s typically the length of the tape,

pub fn bind<'a, D>( &self, vars: &'a ShapeVars<D>, ) -> Result<BoundShape<'a, F, D>, MissingVar>

Binds a shape to a set of variable values

Source

impl<F> Shape<F>

pub fn inner(&self) -> &F

Borrows the inner Function object

Source

impl<F: MathFunction> Shape<F>

pub fn new(ctx: &Context, node: Node) -> Result<Self, BadNode>

Builds a new shape from a math expression with default (X, Y, Z) axes

pub fn new_raw(f: F) -> Self

Raw constructor

Panics

If the function f does not have exactly one output