pub struct ShapeTracingEval<E: TracingEvaluator> { /* private fields */ }Expand description
Wrapper around a TracingEvaluator
Unlike the raw tracing evaluator, a ShapeTracingEval knows about the
tape’s X, Y, Z axes and optional transform matrix.
Implementations
Sourceimpl<E: TracingEvaluator> ShapeTracingEval<E>
impl<E: TracingEvaluator> ShapeTracingEval<E>
Sourcepub fn eval<F: Into<E::Data> + Copy>(
&mut self,
tape: &ShapeTape<E::Tape>,
x: F,
y: F,
z: F,
) -> Result<(E::Data, Option<&E::Trace>), Error>
pub fn eval<F: Into<E::Data> + Copy>( &mut self, tape: &ShapeTape<E::Tape>, x: F, y: F, z: F, ) -> Result<(E::Data, Option<&E::Trace>), Error>
Tracing evaluation of the given tape with X, Y, Z input arguments
Before evaluation, the tape’s transform matrix is applied (if present).
If the tape has other variables, eval_v should be
called instead (and this function will return an error.
Sourcepub fn eval_v<F: Into<E::Data> + Copy, V: Into<E::Data> + Copy>(
&mut self,
tape: &ShapeTape<E::Tape>,
x: F,
y: F,
z: F,
vars: &ShapeVars<V>,
) -> Result<(E::Data, Option<&E::Trace>), Error>
pub fn eval_v<F: Into<E::Data> + Copy, V: Into<E::Data> + Copy>( &mut self, tape: &ShapeTape<E::Tape>, x: F, y: F, z: F, vars: &ShapeVars<V>, ) -> Result<(E::Data, Option<&E::Trace>), Error>
Tracing evaluation of a single sample
Before evaluation, the tape’s transform matrix is applied (if present).