ShapeVars

Struct ShapeVars 

pub struct ShapeVars<F>(/* private fields */);
Variables bound to values for shape evaluation

Note that this cannot store X, Y, Z variables (which are passed in as first-class arguments); it only stores Var::V values (identified by their inner VarIndex).

Implementations

Source

impl<F> ShapeVars<F>

pub fn new() -> Self

Builds a new, empty variable set

pub fn len(&self) -> usize

Returns the number of variables stored in the set

pub fn is_empty(&self) -> bool

Checks whether the variable set is empty

pub fn insert(&mut self, v: VarIndex, f: F) -> Option<F>

Inserts a new variable

Returns the previous value (if present)

pub fn values(&self) -> impl Iterator<Item = &F>

Iterates over values