Module var

Module var 

Input variables to math expressions

A Var maintains a persistent identity from Tree to Context (where it is wrapped in a Op::Input) to evaluation (where Tape::vars maps from Var to index in the argument list).

Structs

BadVarSlice
Error type for when variable slice length does not match expected count
MismatchedSlices
Error type for mismatched slice lengths in bulk evaluation
VarIndex
Type for a variable index (implemented as a u64), used in Var::V
VarMap
Map from Var to a particular index

Enums

BulkArgError
Error type for checking bulk arguments for evaluation
TracingArgError
Error type for checking tracing arguments for evaluation
Var
The Var type is an input to a math expression