pub struct VarMap { /* private fields */ }Expand description
Map from Var to a particular index
Variable indexes are automatically assigned the first time
VarMap::insert is called on that variable.
Indexes are guaranteed to be tightly packed, i.e. a map vars will contains
values from 0..vars.len().
For efficiency, this type does not allocate heap memory for Var::X/Y/Z.
Implementations
Sourceimpl VarMap
impl VarMap
pub fn new() -> Self
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
pub fn get(&self, v: &Var) -> Option<usize>
Sourcepub fn insert(&mut self, v: Var)
pub fn insert(&mut self, v: Var)
Inserts a variable if not already present in the map
The index is automatically assigned.