Module vm

Module vm 

Simple virtual machine for shape evaluation

Structs

EmptyTapeStorage
Tape storage type which indicates that there’s no actual backing storage
GenericVmFunction
VM-backed shape with a configurable number of registers
GenericVmTape
Tape which uses the VM backend for evaluation
VmData
A flattened math expression, ready for evaluation or further compilation.
VmFloatSliceEval
VM-based bulk evaluator for arrays of points, yielding point values
VmGradSliceEval
VM-based bulk evaluator for arrays of points, yielding gradient values
VmIntervalEval
VM-based tracing evaluator for intervals
VmPointEval
VM-based tracing evaluator for single points
VmTrace
A trace captured by a VM evaluation
VmWorkspace
Data structures used during VmData::simplify

Enums

Choice
A single choice made at a min/max node.

Type Aliases

VmFunction
Function which uses the VM backend for evaluation
VmShape
Shape that uses the VmFunction backend for evaluation