pub struct VmTrace(/* private fields */);Expand description
A trace captured by a VM evaluation
This is a thin wrapper around a Vec<Choice>.
Implementations
Sourceimpl VmTrace
impl VmTrace
Sourcepub fn resize(&mut self, n: usize, v: Choice)
pub fn resize(&mut self, n: usize, v: Choice)
Resizes the trace, using the new value if it needs to be extended
Sourcepub fn as_mut_slice(&mut self) -> &mut [Choice]
pub fn as_mut_slice(&mut self) -> &mut [Choice]
Returns the inner choice slice as a mutable reference
Sourcepub fn as_mut_ptr(&mut self) -> *mut Choice
pub fn as_mut_ptr(&mut self) -> *mut Choice
Returns a pointer to the allocated choice array