pub struct RegTape { /* private fields */ }Expand description
Low-level tape for use with the Fidget virtual machine (or to be lowered further into machine instructions).
Implementations
Sourceimpl RegTape
impl RegTape
Sourcepub fn new<const N: usize>(ssa: &SsaTape) -> Self
pub fn new<const N: usize>(ssa: &SsaTape) -> Self
Lowers the tape to assembly with a particular register limit
Note that if you also want to simplify the tape, it’s more efficient
to use VmData::simplify, which
simultaneously simplifies and performs register allocation in a
single pass.
Sourcepub fn slot_count(&self) -> usize
pub fn slot_count(&self) -> usize
Returns the number of unique register and memory locations that are used by this tape.
Sourcepub fn iter(&self) -> impl DoubleEndedIterator<Item = &RegOp>
pub fn iter(&self) -> impl DoubleEndedIterator<Item = &RegOp>
Returns a front-to-back iterator
This is the opposite of evaluation order; it will visit the root of the tree first, and end at the leaves.