pub struct RenderHandle<F: Function, T = ()> { /* private fields */ }Expand description
A RenderHandle contains lazily-populated tapes for rendering
This can be cheaply cloned, although it is usually passed by mutable reference to a recursive function.
The most recent simplification is cached for reuse (if the trace matches).
Implementations
Sourceimpl<F: Function, T> RenderHandle<F, T>
impl<F: Function, T> RenderHandle<F, T>
Sourcepub fn new(shape: Shape<F, T>) -> Self
pub fn new(shape: Shape<F, T>) -> Self
Build a new RenderHandle for the given shape
None of the tapes are populated here.
Sourcepub fn i_tape(
&mut self,
storage: &mut Vec<F::TapeStorage>,
) -> &ShapeTape<<F::IntervalEval as TracingEvaluator>::Tape>
pub fn i_tape( &mut self, storage: &mut Vec<F::TapeStorage>, ) -> &ShapeTape<<F::IntervalEval as TracingEvaluator>::Tape>
Returns a tape for tracing interval evaluation
Sourcepub fn f_tape(
&mut self,
storage: &mut Vec<F::TapeStorage>,
) -> &ShapeTape<<F::FloatSliceEval as BulkEvaluator>::Tape>
pub fn f_tape( &mut self, storage: &mut Vec<F::TapeStorage>, ) -> &ShapeTape<<F::FloatSliceEval as BulkEvaluator>::Tape>
Returns a tape for bulk float evaluation
Sourcepub fn g_tape(
&mut self,
storage: &mut Vec<F::TapeStorage>,
) -> &ShapeTape<<F::GradSliceEval as BulkEvaluator>::Tape>
pub fn g_tape( &mut self, storage: &mut Vec<F::TapeStorage>, ) -> &ShapeTape<<F::GradSliceEval as BulkEvaluator>::Tape>
Returns a tape for bulk gradient evaluation
Sourcepub fn simplify(
&mut self,
trace: &F::Trace,
workspace: &mut F::Workspace,
shape_storage: &mut Vec<F::Storage>,
tape_storage: &mut Vec<F::TapeStorage>,
) -> &mut Self
pub fn simplify( &mut self, trace: &F::Trace, workspace: &mut F::Workspace, shape_storage: &mut Vec<F::Storage>, tape_storage: &mut Vec<F::TapeStorage>, ) -> &mut Self
Simplifies the shape with the given trace
As an internal optimization, this may reuse a previous simplification if the trace matches.