pub struct TileSizes(/* private fields */);Expand description
Container representing an ordered, checked list of tile sizes
This object wraps a Vec<usize>, guaranteeing three invariants:
- There must be at least one tile size
- Tiles must be ordered from largest to smallest
- Each tile size must be exactly divisible by subsequent tile sizes
Implementations