Shape

Struct Shape 

pub struct Shape<F, T = ()> { /* private fields */ }
A shape represents an implicit surface

It is mostly agnostic to how that surface is represented, wrapping a Function and a set of axes.

Shapes are shared between threads, so they should be cheap to clone. In most cases, they’re a thin wrapper around an Arc<..>.

At construction, a shape has no associated transformation. A transformation matrix can be applied by calling Shape::with_transform.

The shape’s transformation matrix is propagated into tapes (constructed by *_tape functions), which use the matrix to transform incoming coordinates during evaluation.

Note that with_transform returns a Shape with Transformed as the second template parameter; to preserve immutability, the marker prevents further mutation of the transform.

Implementations

Source

impl<F: Function + Clone, T> Shape<F, T>

pub fn new_point_eval() -> ShapeTracingEval<F::PointEval>

Builds a new point evaluator

pub fn new_interval_eval() -> ShapeTracingEval<F::IntervalEval>

Builds a new interval evaluator

pub fn new_float_slice_eval() -> ShapeBulkEval<F::FloatSliceEval>

Builds a new float slice evaluator

pub fn new_grad_slice_eval() -> ShapeBulkEval<F::GradSliceEval>

Builds a new gradient slice evaluator

pub fn point_tape( &self, storage: F::TapeStorage, ) -> ShapeTape<<F::PointEval as TracingEvaluator>::Tape>

Returns an evaluation tape for a point evaluator

pub fn interval_tape( &self, storage: F::TapeStorage, ) -> ShapeTape<<F::IntervalEval as TracingEvaluator>::Tape>

Returns an evaluation tape for a interval evaluator

pub fn float_slice_tape( &self, storage: F::TapeStorage, ) -> ShapeTape<<F::FloatSliceEval as BulkEvaluator>::Tape>

Returns an evaluation tape for a float slice evaluator

pub fn grad_slice_tape( &self, storage: F::TapeStorage, ) -> ShapeTape<<F::GradSliceEval as BulkEvaluator>::Tape>

Returns an evaluation tape for a gradient slice evaluator

pub fn simplify( &self, trace: &F::Trace, storage: F::Storage, workspace: &mut F::Workspace, ) -> Result<Self, Error>
where Self: Sized,

Computes a simplified tape using the given trace, and reusing storage

pub fn recycle(self) -> Option<F::Storage>

Attempt to reclaim storage from this shape

This may fail, because shapes are Clone and are often implemented using an Arc around a heavier data structure.

pub fn size(&self) -> usize

Returns a size associated with this shape

This is underspecified and only used for unit testing; for tape-based shapes, it’s typically the length of the tape,

Source

impl<F, T> Shape<F, T>

pub fn inner(&self) -> &F

Borrows the inner Function object

pub fn axes(&self) -> &[Var; 3]

Borrows the inner axis mapping

pub fn new_raw(f: F, axes: [Var; 3]) -> Self

Raw constructor

Source

impl<F: Clone> Shape<F, ()>

pub fn with_transform(&self, mat: Matrix4<f32>) -> Shape<F, Transformed>

Returns a shape with the given transform applied

Source

impl<F: Clone> Shape<F, Transformed>

pub fn transform(&self) -> Matrix4<f32>

Returns the currently-applied transform matrix

Source

impl<F: MathFunction> Shape<F>

pub fn new_with_axes( ctx: &Context, node: Node, axes: [Var; 3], ) -> Result<Self, Error>

Builds a new shape from a math expression with the given axes

pub fn new(ctx: &Context, node: Node) -> Result<Self, Error>
where Self: Sized,

Builds a new shape from the given node with default (X, Y, Z) axes