pub struct Shape<F, T = ()> { /* private fields */ }Expand description
A shape represents an implicit surface
It is mostly agnostic to how that surface is represented, wrapping a
Function and a set of axes.
Shapes are shared between threads, so they should be cheap to clone. In
most cases, they’re a thin wrapper around an Arc<..>.
At construction, a shape has no associated transformation. A transformation
matrix can be applied by calling Shape::with_transform.
The shape’s transformation matrix is propagated into tapes (constructed by
*_tape functions), which use the matrix to transform incoming coordinates
during evaluation.
Note that with_transform returns a Shape with Transformed as the
second template parameter; to preserve immutability, the marker prevents
further mutation of the transform.
Implementations
Sourceimpl<F: Function + Clone, T> Shape<F, T>
impl<F: Function + Clone, T> Shape<F, T>
Sourcepub fn new_point_eval() -> ShapeTracingEval<F::PointEval>
pub fn new_point_eval() -> ShapeTracingEval<F::PointEval>
Builds a new point evaluator
Sourcepub fn new_interval_eval() -> ShapeTracingEval<F::IntervalEval>
pub fn new_interval_eval() -> ShapeTracingEval<F::IntervalEval>
Builds a new interval evaluator
Sourcepub fn new_float_slice_eval() -> ShapeBulkEval<F::FloatSliceEval>
pub fn new_float_slice_eval() -> ShapeBulkEval<F::FloatSliceEval>
Builds a new float slice evaluator
Sourcepub fn new_grad_slice_eval() -> ShapeBulkEval<F::GradSliceEval>
pub fn new_grad_slice_eval() -> ShapeBulkEval<F::GradSliceEval>
Builds a new gradient slice evaluator
Sourcepub fn point_tape(
&self,
storage: F::TapeStorage,
) -> ShapeTape<<F::PointEval as TracingEvaluator>::Tape>
pub fn point_tape( &self, storage: F::TapeStorage, ) -> ShapeTape<<F::PointEval as TracingEvaluator>::Tape>
Returns an evaluation tape for a point evaluator
Sourcepub fn interval_tape(
&self,
storage: F::TapeStorage,
) -> ShapeTape<<F::IntervalEval as TracingEvaluator>::Tape>
pub fn interval_tape( &self, storage: F::TapeStorage, ) -> ShapeTape<<F::IntervalEval as TracingEvaluator>::Tape>
Returns an evaluation tape for a interval evaluator
Sourcepub fn float_slice_tape(
&self,
storage: F::TapeStorage,
) -> ShapeTape<<F::FloatSliceEval as BulkEvaluator>::Tape>
pub fn float_slice_tape( &self, storage: F::TapeStorage, ) -> ShapeTape<<F::FloatSliceEval as BulkEvaluator>::Tape>
Returns an evaluation tape for a float slice evaluator
Sourcepub fn grad_slice_tape(
&self,
storage: F::TapeStorage,
) -> ShapeTape<<F::GradSliceEval as BulkEvaluator>::Tape>
pub fn grad_slice_tape( &self, storage: F::TapeStorage, ) -> ShapeTape<<F::GradSliceEval as BulkEvaluator>::Tape>
Returns an evaluation tape for a gradient slice evaluator
Sourcepub fn simplify(
&self,
trace: &F::Trace,
storage: F::Storage,
workspace: &mut F::Workspace,
) -> Result<Self, Error>where
Self: Sized,
pub fn simplify(
&self,
trace: &F::Trace,
storage: F::Storage,
workspace: &mut F::Workspace,
) -> Result<Self, Error>where
Self: Sized,
Computes a simplified tape using the given trace, and reusing storage
Sourceimpl<F: Clone> Shape<F, ()>
impl<F: Clone> Shape<F, ()>
Sourcepub fn with_transform(&self, mat: Matrix4<f32>) -> Shape<F, Transformed>
pub fn with_transform(&self, mat: Matrix4<f32>) -> Shape<F, Transformed>
Returns a shape with the given transform applied
Sourceimpl<F: Clone> Shape<F, Transformed>
impl<F: Clone> Shape<F, Transformed>