ShapeBulkEval

Struct ShapeBulkEval 

pub struct ShapeBulkEval<E: BulkEvaluator> { /* private fields */ }
Wrapper around a BulkEvaluator

Unlike the raw bulk evaluator, a ShapeBulkEval knows about the tape’s X, Y, Z axes and optional transform matrix.

Implementations

Source

impl<E: BulkEvaluator> ShapeBulkEval<E>
where E::Data: From<f32> + Transformable,

pub fn eval( &mut self, tape: &ShapeTape<E::Tape>, x: &[E::Data], y: &[E::Data], z: &[E::Data], ) -> Result<&[E::Data], Error>

Bulk evaluation of many samples, without any variables

If the shape includes variables other than X, Y, Z, eval_v or eval_vs should be used instead (and this function will return an error).

Before evaluation, the tape’s transform matrix is applied (if present).

pub fn eval_vs<V: Deref<Target = [G]>, G: Into<E::Data> + Copy>( &mut self, tape: &ShapeTape<E::Tape>, x: &[E::Data], y: &[E::Data], z: &[E::Data], vars: &ShapeVars<V>, ) -> Result<&[E::Data], Error>

Bulk evaluation of many samples, with slices of variables

Each variable is a slice (or Vec) of values, which must be the same length as the x, y, z slices. This is in contrast with eval_vs, where variables have a single value used for every position in the x, y, z slices.

Before evaluation, the tape’s transform matrix is applied (if present).

pub fn eval_v<G: Into<E::Data> + Copy>( &mut self, tape: &ShapeTape<E::Tape>, x: &[E::Data], y: &[E::Data], z: &[E::Data], vars: &ShapeVars<G>, ) -> Result<&[E::Data], Error>

Bulk evaluation of many samples, with fixed variables

Each variable has a single value, which is used for every position in the x, y, z slices. This is in contrast with eval_vs, where variables can be different for every position in the x, y, z slices.

Before evaluation, the tape’s transform matrix is applied (if present).