pub struct ShapeBulkEval<E: BulkEvaluator> { /* private fields */ }Expand description
Wrapper around a BulkEvaluator
Unlike the raw bulk evaluator, a ShapeBulkEval knows about the
tape’s X, Y, Z axes and optional transform matrix.
Implementations
Sourceimpl<E: BulkEvaluator> ShapeBulkEval<E>
impl<E: BulkEvaluator> ShapeBulkEval<E>
Sourcepub fn eval(
&mut self,
tape: &ShapeTape<E::Tape>,
x: &[E::Data],
y: &[E::Data],
z: &[E::Data],
) -> Result<&[E::Data], Error>
pub fn eval( &mut self, tape: &ShapeTape<E::Tape>, x: &[E::Data], y: &[E::Data], z: &[E::Data], ) -> Result<&[E::Data], Error>
Sourcepub fn eval_vs<V: Deref<Target = [G]>, G: Into<E::Data> + Copy>(
&mut self,
tape: &ShapeTape<E::Tape>,
x: &[E::Data],
y: &[E::Data],
z: &[E::Data],
vars: &ShapeVars<V>,
) -> Result<&[E::Data], Error>
pub fn eval_vs<V: Deref<Target = [G]>, G: Into<E::Data> + Copy>( &mut self, tape: &ShapeTape<E::Tape>, x: &[E::Data], y: &[E::Data], z: &[E::Data], vars: &ShapeVars<V>, ) -> Result<&[E::Data], Error>
Bulk evaluation of many samples, with slices of variables
Each variable is a slice (or Vec) of values, which must be the same
length as the x, y, z slices. This is in contrast with
eval_vs, where variables have a single value used for
every position in the x, y, z slices.
Before evaluation, the tape’s transform matrix is applied (if present).
Sourcepub fn eval_v<G: Into<E::Data> + Copy>(
&mut self,
tape: &ShapeTape<E::Tape>,
x: &[E::Data],
y: &[E::Data],
z: &[E::Data],
vars: &ShapeVars<G>,
) -> Result<&[E::Data], Error>
pub fn eval_v<G: Into<E::Data> + Copy>( &mut self, tape: &ShapeTape<E::Tape>, x: &[E::Data], y: &[E::Data], z: &[E::Data], vars: &ShapeVars<G>, ) -> Result<&[E::Data], Error>
Bulk evaluation of many samples, with fixed variables
Each variable has a single value, which is used for every position in
the x, y, z slices. This is in contrast with
eval_vs, where variables can be different for every
position in the x, y, z slices.
Before evaluation, the tape’s transform matrix is applied (if present).