Input variables to math expressions
A Var maintains a persistent identity from
Tree to Context (where
it is wrapped in a Op::Input) to evaluation
(where Tape::vars maps from Var to index in
the argument list).
Structs
- BadVar
Slice - Error type for when variable slice length does not match expected count
- Mismatched
Slices - Error type for mismatched slice lengths in bulk evaluation
- VarIndex
- Type for a variable index (implemented as a
u64), used inVar::V - VarMap
- Map from
Varto a particular index
Enums
- Bulk
ArgError - Error type for checking bulk arguments for evaluation
- Tracing
ArgError - Error type for checking tracing arguments for evaluation
- Var
- The
Vartype is an input to a math expression